@@ -32,6 +32,8 @@ def onEEGPowerRecieved(eegSignal):
     print("Low Gamma value: %d" % eegSignal.lGamma)
     print("Medium gamma value: %d" % eegSignal.mGamma)
 
+def onRawSignal(rawSignal):
+    print("RAW: %d" % rawSignal)
 
 pinapsController = PiNapsController()
 
@@ -44,6 +46,7 @@ if __name__ == '__main__':
     blinoParser.attentionCallback = onAttention
     blinoParser.meditationCallback = onMedititation
     blinoParser.eegPowersCallback = onEEGPowerRecieved
+    #blinoParser.rawSignalCallback = onRawSignal
 
     pinapsController.deactivateAllLEDs() 
 
@@ -53,3 +56,5 @@ if __name__ == '__main__':
             #blinoParser.parseByte(data)
             data = pinapsController.readEEGSensor()
             blinoParser.parse(data)
+
+            print("NUM:" + str(pinapsController.dataWaiting()))
